"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 09.11.20

"""
import logging

from django.core.mail import send_mail
from django.template.loader import render_to_string
from django.utils.translation import gettext_lazy as _

from konova.sub_settings.django_settings import DEFAULT_FROM_EMAIL

logger = logging.getLogger(__name__)


class Mailer:
    """
    A wrapper for the django internal mailing functionality
    """
    from_mail = None
    to_mail = []
    fail_silently = False

    # Optional. Can be changed using the constructor to authenticate on the smtp server using other credentials
    auth_user = None
    auth_password = None

    def __init__(self, from_mail: str = DEFAULT_FROM_EMAIL, auth_user: str = None, auth_password: str = None, fail_silently: bool = False):
        self.from_mail = from_mail
        self.fail_silently = fail_silently
        self.auth_user = auth_user
        self.auth_password = auth_password

    def send(self, recipient_list: list, subject: str, msg: str):
        """
        Sends a mail with subject and message
        """
        return send_mail(
            subject=subject,
            message=msg,
            from_email=self.from_mail,
            recipient_list=recipient_list,
            fail_silently=self.fail_silently,
            auth_user=self.auth_user,
            auth_password=self.auth_password
        )

    def send_mail_shared_access_removed(self, obj, user):
        """ Send a mail if user has no access to the object anymore

        Args:
            obj ():

        Returns:

        """
        context = {
            "user": user,
            "obj": obj,
        }
        msg = render_to_string("email/sharing/shared_access_removed.html", context)
        user_mail_address = [user.email]
        self.send(
            user_mail_address,
            _("{} - Shared access removed").format(obj.identifier),
            msg
        )

